@@ -670,7 +670,7 @@ class Bugz:
     def search(self, query, comments = False, order = 'number',
                assigned_to = None, reporter = None, cc = None,
                whiteboard = None, keywords = None,
-               status = [], severity = [], priority = [], component = [], product = []):
+               status = [], severity = [], priority = [], component = [], product = [], date_from = None, date_to = None):
         """Search bugzilla for a bug.
 
         @param query: query string to search in title or {comments}.
@@ -728,6 +728,9 @@ class Bugz:
         qparams['status_whiteboard'] = whiteboard or ''
         qparams['keywords'] = keywords or ''
 
+        qparams['chfieldfrom'] = date_from or ''
+        qparams['chfieldto'] = date_to or ''
+		
         # hoops to jump through for emails, since there are
         # only two fields, we have to figure out what combinations
         # to use if all three are set.
