@@ -19,6 +19,18 @@ parar = False
 ## if you use OS2008, distro = 'chinook'
 ## else, distro = 'bora' or anything
 distro = 'chinook'
+## if run mabugz in local directory running = 'sdk'
+## else running = 'OS' or anything
+running = 'OS'
+
+if running == 'sdk':
+	configdir = ''
+	appdir = ''
+	imgdir = 'pixmaps/'
+else:
+	configdir = '/home/user/.mabugz/'
+	appdir = '/usr/share/mabugz/'
+	imgdir = appdir + 'pixmaps/'	
 
 (
     COLUMN_NUMBER,
@@ -42,31 +54,56 @@ osso_c = osso.Context("py_mabugz", "0.0.3", False)
 
 (ENABLED, TITLE, URL, USER, PASS) = range(5)
 cuentas=[]
+
+##Check if there is settings, if not create new ##
+## If file is corrupted, create new ##
+## If settings.conf haven't fontsize (new feature), add it ###
+def if_config_not_exist_create_it():
+	if os.path.exists(configdir + "settings.conf"):
+		print 'settings.conf exist'
+		settings_conf =  open(configdir + "settings.conf", "r")
+		settings_read = settings_conf.read()
+		settings_conf.close()
+		if settings_read.find('[Settings]') < 0:
+			print 'settings.conf is corrupted'
+			create_settings_files('settings')
+		del settings_read
+	else:
+		create_settings_files('settings')
+
+	if os.path.exists(configdir + "accounts.conf"):
+		print 'accounts.conf exist'
+		accounts_conf =  open(configdir + "accounts.conf", "r")
+		if accounts_conf.read() == '':
+			print 'accounts.conf is corrupted'
+			create_settings_files('accounts')
+		accounts_conf.close()
+	else:
+		create_settings_files('accounts')
+
+def create_settings_files(setting):
+	if setting == 'accounts':
+		print 'creating new accounts.conf'
+		new_config = "[maemo]\nurl = http://bugs.maemo.org\npassword = \nenabled = True\nuser = \n\n[Gnome]\nurl = http://bugzilla.gnome.org\npassword = \nenabled = False\nuser = "
+		fileconfig = open(configdir + "accounts.conf", "w")
+		fileconfig.write(new_config)
+		fileconfig.close()	
+	if setting == 'settings':
+		print 'creating new settings.conf'
+		new_config = "[Settings]\nfingerscroll = True\ncomments = False\ntext_color = #0000FF"
+		fileconfig = open(configdir + "settings.conf", "w")
+		fileconfig.write(new_config)
+		fileconfig.close()
+
+if_config_not_exist_create_it()
 	
 config = ConfigParser.SafeConfigParser()
-if os.path.exists("/home/user/.mabugz/settings.conf"):
-	config.read("/home/user/.mabugz/settings.conf")
-elif os.path.exists("settings.conf"): 
-	config.read("settings.conf")
-else:
-	a=open("/home/user/.mabugz/settings.conf", "w")
-	a.close()
-	config.read("/home/user/.mabugz/settings.conf")
+config.read(configdir + "settings.conf")
 
 accounts = ConfigParser.SafeConfigParser()
-if os.path.exists("/home/user/.mabugz/accounts.conf"):
-	accounts.read("/home/user/.mabugz/accounts.conf")
-elif os.path.exists("accounts.conf"): 
-	accounts.read("accounts.conf")
-else:
-	a=open("/home/user/.mabugz/accounts.conf", "w")
-	a.close()
-	accounts.read("/home/user/.mabugz/accounts.conf")
+accounts.read(configdir + "accounts.conf")
 
-if os.path.exists("/usr/share/mabugz/preferences.glade"):
-	preferences_glade = "/usr/share/mabugz/preferences.glade"
-else: 
-	preferences_glade = "preferences.glade"	
+preferences_glade = appdir + "preferences.glade"	
 
 class PyBugz(hildon.Program):
 	def __init__(self):
@@ -79,7 +116,7 @@ class PyBugz(hildon.Program):
 		self.window_in_fullscreen = False 
 		
 ## Set settings
-		####debug####	
+		####debug this but it *should* work well####	
 		for section in accounts.sections():
 			if accounts.get(section, "enabled") == 'True':
 				#print 'account: ', section	
@@ -100,11 +137,6 @@ class PyBugz(hildon.Program):
 			child.reparent(menu)
 		self.MainWindow.set_menu(self.menubar)
 
-		if os.path.exists("/usr/share/mabugz/pixmaps/"):
-			imgdir = "/usr/share/mabugz/pixmaps/"
-		else:
-			imgdir = "pixmaps/"
-
 		self.menu_exit = gtk.ImageMenuItem("Exit")		
 		exit_img = gtk.Image()
 		exit_img.set_from_file(imgdir + "gtk-quit.png")
@@ -630,7 +662,7 @@ class PyBugz(hildon.Program):
 		column = gtk.TreeViewColumn('Description', gtk.CellRendererText(),
                                      text=COLUMN_DESCRIPTION)
 		column.set_sort_column_id(COLUMN_DESCRIPTION)
-		column.set_min_width(400)
+		column.set_min_width(550)
 		column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
 		column.set_resizable(True)
 		treeview.append_column(column)
@@ -780,9 +812,9 @@ class PyBugz(hildon.Program):
 					COLUMN_SEVERITY, one_result[COLUMN_SEVERITY],
 					COLUMN_PRODUCT, one_result[COLUMN_PRODUCT])
 				gtk.gdk.threads_leave()
-		
 		except:
 			print "An error occurred searching bugs. Perhaps that bugzilla doesn't allow empty searches."
+
 		self.pgbar.stop_pg()
 		self._do_widgets_sensitive()
 
@@ -980,11 +1012,6 @@ class GetBug:
 			child.reparent(menu)
 		self.BugWindow.set_menu(self.menubar)
 
-		if os.path.exists("/usr/share/mabugz/pixmaps"):
-			imgdir = "/usr/share/mabugz/pixmaps/"
-		else:
-			imgdir = "pixmaps/"
-
 		self.menu_modify = gtk.ImageMenuItem("Modify")		
 		modify_img = gtk.Image()
 		modify_img.set_from_file(imgdir + "gtk-modify.png")
@@ -1093,11 +1120,6 @@ class GetBug:
 		for child in menubar.get_children():
 			child.reparent(menu)
 		self.modify_win.set_menu(menubar)
-		
-		if os.path.exists("/usr/share/mabugz/pixmaps/"):
-			imgdir = "/usr/share/mabugz/pixmaps/"
-		else:
-			imgdir = "pixmaps/"	
 
 		menu_send = gtk.ImageMenuItem("Send")		
 		send_img = gtk.Image()
@@ -1194,7 +1216,7 @@ class GetBug:
 		
 		try:
 			result = pybugz.modify(bugid, title = None, comment = comment, url = url, status = None, resolution = None, assigned_to = None, duplicate = 0, priority = None, severity = None, add_cc = [add_cc], remove_cc = [remove_cc], add_dependson = [], remove_dependson = [], add_blocked = [], remove_blocked = [], whiteboard = None, keywords = None)
-			#print result
+			print result
 			self.pgbar.stop_pg()
 			thread.start_new_thread(MsgDialog, (gtk.MESSAGE_INFO, "Bug modified."))
 			self.modify_win.destroy()
@@ -1406,13 +1428,10 @@ class Credits:
 		dialog.set_name("Mabugz")
 		dialog.set_version("0.0.3")
 		dialog.set_copyright("Copyright © 2007")
-		dialog.set_website("https://garage.maemo.org/projects/mabugz/")
+		dialog.set_website("http://mabugz.garage.maemo.org")
 		dialog.set_authors(["Daniel Martín Yerga <dyerga@gmail.com>", "", "PyBugz module written by:", "Alastair Tse <alastair@liquidx.net>"])
 		dialog.set_artists(["Mabugz logo by Daniel Martin Yerga", "Icons from Gartoon Iconset. GPL License."])
-		try:
- 			logo = gtk.gdk.pixbuf_new_from_file("/usr/share/mabugz/pixmaps/logo.png")
-		except:
-			logo = gtk.gdk.pixbuf_new_from_file("pixmaps/logo.png")
+		logo = gtk.gdk.pixbuf_new_from_file(imgdir + "logo.png")
 		dialog.set_logo(logo)
 		dialog.set_license("This program is released under the GNU\nGeneral Public License. Please visit \nhttp://www.gnu.org/copyleft/gpl.html\nfor details.")
 		dialog.run()
@@ -1420,11 +1439,7 @@ class Credits:
 
 class ProgressBar:
 	def __init__(self, pg_text, window):
-		if os.path.exists("/usr/share/mabugz/progressbar.glade"):
-			self.prog_file = "/usr/share/mabugz/progressbar.glade"
-		else:
-			self.prog_file = "progressbar.glade"
-			
+		self.prog_file = appdir + "progressbar.glade"
 		self.progTree = gtk.glade.XML(self.prog_file)
 		self.w = self.progTree.get_widget("dialog1")
 		self.w.set_transient_for(window)
@@ -1504,7 +1519,6 @@ class Preferences:
 		button3 = self.acctree.get_widget("button3")
 		button3.connect("clicked", self.close_preferences)
 	
-		
 		#### Others tab ####
 		self.color_button = gtk.ColorButton()
 		try:
@@ -1549,7 +1563,7 @@ class Preferences:
 		BugsSettings.Comments = str(self.comm_button.get_active())
 		BugsSettings.Fingermenu = str(self.menufinger.get_active())
 
-		settings_file=open('/home/user/.mabugz/settings.conf', 'w')	
+		settings_file=open(configdir + 'settings.conf', 'w')	
 		config.set("Settings", "fingerscroll", str(self.menufinger.get_active()))
 		config.set("Settings", "comments", str(self.comm_button.get_active()))
 		config.set("Settings", "text_color", text_color)
@@ -1649,11 +1663,12 @@ class Preferences:
 					#print 'def true acc modifi: ', new_default_acc
 					cuentas[true_indice] = new_default_acc
 				except:
-					print 'bad thing occurred.'
+					#print 'DEFAULT QUE PASA'
+					pass
 			
 			#print cuentas
 			
-			accounts_file=open('/home/user/.mabugz/accounts.conf', 'w')
+			accounts_file=open(configdir + 'accounts.conf', 'w')
 			for title_account in accounts.sections():
 				accounts.set(title_account, "enabled", 'False')
 			accounts.set(newtitle, "enabled", 'True')
@@ -1782,7 +1797,7 @@ class Preferences:
 		##poner default a una nada mas
 		self.make_default(None)
 
-		accounts_file=open('/home/user/.mabugz/accounts.conf', 'w')
+		accounts_file=open(configdir + 'accounts.conf', 'w')
 		try:
 			for title_account in accounts.sections():
 				accounts.set(title_account, "enabled", 'False')
@@ -1860,7 +1875,7 @@ class Preferences:
 			BugsSettings.Password = new_def_pass 
 			#print 'NUEVOS SETTINGS: %s %s %s' % (BugsSettings.URL, BugsSettings.Username, BugsSettings.Password)
 		
-		accounts_file=open('/home/user/.mabugz/accounts.conf', 'w')
+		accounts_file=open(configdir + 'accounts.conf', 'w')
 		try:
 			for title_account in accounts.sections():
 				accounts.set(title_account, "enabled", 'False')
@@ -1917,7 +1932,7 @@ class Preferences:
 			BugsSettings.Password = new_def_pass 
 			#print 'NUEVOS SETTINGS: %s %s %s' % (BugsSettings.URL, BugsSettings.Username, BugsSettings.Password)
 		
-		accounts_file=open('/home/user/.mabugz/accounts.conf', 'w')
+		accounts_file=open(configdir + 'accounts.conf', 'w')
 		try:
 			accounts.remove_section(self.modify_title)	
 			accounts.write(accounts_file)
